Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/__init__.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/__init__.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/__init__.py	(revision 7811)
@@ -2,11 +2,11 @@
 """
 # Make this a package.
-from waeup.sirp.applicants.applicant import (
+from waeup.kofa.applicants.applicant import (
     Applicant, ApplicantFactory, ApplicantImageStoreHandler,
     ApplicantImageNameChooser,
     )
-from waeup.sirp.applicants.container import ApplicantsContainer
-from waeup.sirp.applicants.root import ApplicantsRoot
-from waeup.sirp.applicants.dynamicroles import (
+from waeup.kofa.applicants.container import ApplicantsContainer
+from waeup.kofa.applicants.root import ApplicantsRoot
+from waeup.kofa.applicants.dynamicroles import (
     ApplicantPrincipalRoleManager,)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/applicant.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/applicant.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/applicant.py	(revision 7811)
@@ -26,14 +26,14 @@
 from zope.interface import implementedBy
 from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
-from waeup.sirp.app import University
-from waeup.sirp.image import SIRPImageFile
-from waeup.sirp.imagestorage import DefaultFileStoreHandler
-from waeup.sirp.interfaces import (
-    IObjectHistory, IFileStoreHandler, IFileStoreNameChooser, ISIRPUtils,
+from waeup.kofa.app import University
+from waeup.kofa.image import KOFAImageFile
+from waeup.kofa.imagestorage import DefaultFileStoreHandler
+from waeup.kofa.interfaces import (
+    IObjectHistory, IFileStoreHandler, IFileStoreNameChooser, IKOFAUtils,
     IExtFileStore, IPDF, IUserAccount)
-from waeup.sirp.students.vocabularies import RegNumNotInSource
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.applicants.interfaces import IApplicant, IApplicantEdit
-from waeup.sirp.applicants.workflow import application_states_dict
+from waeup.kofa.students.vocabularies import RegNumNotInSource
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.applicants.interfaces import IApplicant, IApplicantEdit
+from waeup.kofa.applicants.workflow import application_states_dict
 
 class Applicant(grok.Container):
@@ -76,6 +76,6 @@
     def display_fullname(self):
         middlename = getattr(self, 'middlename', None)
-        sirp_utils = getUtility(ISIRPUtils)
-        return sirp_utils.fullname(self.firstname, self.lastname, middlename)
+        kofa_utils = getUtility(IKOFAUtils)
+        return kofa_utils.fullname(self.firstname, self.lastname, middlename)
 
     def createStudent(self, view=None):
@@ -196,5 +196,5 @@
 
     This chooser is registered as an adapter providing
-    :class:`waeup.sirp.interfaces.IFileStoreNameChooser`.
+    :class:`waeup.kofa.interfaces.IFileStoreNameChooser`.
 
     File store name choosers like this one are only convenience
@@ -203,5 +203,5 @@
     manually setting up filenames for applicants.
 
-    .. seealso:: :mod:`waeup.sirp.imagestorage`
+    .. seealso:: :mod:`waeup.kofa.imagestorage`
 
     """
@@ -291,5 +291,5 @@
             ApplicantImageStoreHandler, self).createFile(
             store, root,  filename, file_id, file)
-        return file, path, SIRPImageFile(
+        return file, path, KOFAImageFile(
             file_obj.filename, file_obj.data)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/authentication.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/authentication.py	(revision 7811)
@@ -21,7 +21,7 @@
 import grok
 from zope.pluggableauth.interfaces import IAuthenticatorPlugin
-from waeup.sirp.interfaces import IAuthPluginUtility, IUserAccount
-from waeup.sirp.applicants.interfaces import IApplicant
-from waeup.sirp.students.authentication import (
+from waeup.kofa.interfaces import IAuthPluginUtility, IUserAccount
+from waeup.kofa.applicants.interfaces import IApplicant
+from waeup.kofa.students.authentication import (
     StudentAccount, StudentsAuthenticatorPlugin)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/batching.py	(revision 7811)
@@ -24,8 +24,8 @@
 from zope.component import queryUtility
 from zope.catalog.interfaces import ICatalog
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IBatchProcessor, IObjectConverter, FatalCSVError)
-from waeup.sirp.utils.batching import BatchProcessor
-from waeup.sirp.applicants.interfaces import (
+from waeup.kofa.utils.batching import BatchProcessor
+from waeup.kofa.applicants.interfaces import (
     IApplicantsContainer, IApplicant, IApplicantUpdateByRegNo)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantdisplaypage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantdisplaypage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantdisplaypage.pt	(revision 7811)
@@ -11,5 +11,5 @@
 <img src="" tal:attributes="src view/passport_url" />
 
-<table i18n:domain="waeup.sirp" class="form-table">
+<table i18n:domain="waeup.kofa" class="form-table">
   <tbody>
     <tal:block repeat="widget view/widgets">
@@ -41,8 +41,8 @@
   </tbody>
 </table>
-<h3  i18n:domain="waeup.sirp" i18n:translate="">
+<h3  i18n:domain="waeup.kofa" i18n:translate="">
     Acceptance Fee Payment Tickets
 </h3>
-<table i18n:domain="waeup.sirp">
+<table i18n:domain="waeup.kofa">
   <thead>
     <tr>
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicanteditpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicanteditpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicanteditpage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <h2>
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantregemailsent.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantregemailsent.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantregemailsent.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<div i18n:domain="waeup.sirp">
+<div i18n:domain="waeup.kofa">
   <p>
     <span i18n:translate=""> An email with your user name and password
@@ -10,5 +10,5 @@
   </p>
   <p  i18n:translate="">
-    Thanks for using SIRP!
+    Thanks for using Kofa!
   </p>
 </div>
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantregister.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantregister.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantregister.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-    i18n:domain="waeup.sirp" enctype="multipart/form-data">
+    i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <table class="form-table">
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantscontainermanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantscontainermanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantscontainermanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-  i18n:domain="waeup.sirp" class="edit-form" enctype="multipart/form-data">
+  i18n:domain="waeup.kofa" class="edit-form" enctype="multipart/form-data">
 
   <ul class="tabs" data-tabs="tabs">
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantsrootmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantsrootmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantsrootmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL"
-  i18n:domain="waeup.sirp" method="POST"  enctype="multipart/form-data">
+  i18n:domain="waeup.kofa" method="POST"  enctype="multipart/form-data">
   <ul class="tabs" data-tabs="tabs">
     <li class="active">
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantsrootpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantsrootpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser_templates/applicantsrootpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table i18n:domain="waeup.sirp">
+<table i18n:domain="waeup.kofa">
   <thead>
     <tr>
@@ -11,5 +11,5 @@
     <tr tal:repeat="entry context/values" class="gradeC">
       <td tal:content="entry/year">Year
-      </td>	
+      </td>
       <td tal:content="entry/__name__">CODE
       </td>
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/container.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/container.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/container.py	(revision 7811)
@@ -23,9 +23,9 @@
 from zope.component.factory import Factory
 from zope.component.interfaces import IFactory
-from waeup.sirp.applicants.interfaces import (
+from waeup.kofa.applicants.interfaces import (
     IApplicantsContainer, IApplicantsContainerAdd,
     IApplicantsContainerProvider, IApplicant
     )
-from waeup.sirp.utils.helpers import attrs_to_fields
+from waeup.kofa.utils.helpers import attrs_to_fields
 
 def generate_applicant_id(container=None):
@@ -111,5 +111,5 @@
     """
     grok.implements(IApplicantsContainerProvider)
-    grok.name('waeup.sirp.applicants.ApplicantsContainer')
+    grok.name('waeup.kofa.applicants.ApplicantsContainer')
 
     #: The applicants container type this provider provides:
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/dynamicroles.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/dynamicroles.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/dynamicroles.py	(revision 7811)
@@ -24,6 +24,6 @@
 import grok
 from zope.securitypolicy.interfaces import IPrincipalRoleManager
-from waeup.sirp.applicants.interfaces import IApplicant
-from waeup.sirp.students.dynamicroles import StudentPrincipalRoleManager
+from waeup.kofa.applicants.interfaces import IApplicant
+from waeup.kofa.students.dynamicroles import StudentPrincipalRoleManager
 
 # All components in here have the same context: Applicant instances
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py	(revision 7811)
@@ -27,13 +27,13 @@
 from zope.schema.interfaces import (
     ValidationError, ISource, IContextSourceBinder)
-from waeup.sirp.schema import TextLineChoice
-from waeup.sirp.interfaces import (
-    ISIRPObject, year_range, validate_email, academic_sessions_vocab)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.payments.interfaces import IOnlinePayment
-from waeup.sirp.schoolgrades import ResultEntryField
-from waeup.sirp.students.vocabularies import (
+from waeup.kofa.schema import TextLineChoice
+from waeup.kofa.interfaces import (
+    IKOFAObject, year_range, validate_email, academic_sessions_vocab)
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.payments.interfaces import IOnlinePayment
+from waeup.kofa.schoolgrades import ResultEntryField
+from waeup.kofa.students.vocabularies import (
     lgas_vocab, CertificateSource, GenderSource)
-from waeup.sirp.university.vocabularies import (
+from waeup.kofa.university.vocabularies import (
     course_levels, AppCatSource)
 
@@ -178,10 +178,10 @@
     pass
 
-class IApplicantsRoot(ISIRPObject, IContainer):
+class IApplicantsRoot(IKOFAObject, IContainer):
     """A container for university applicants containers.
     """
     pass
 
-class IApplicantsContainer(ISIRPObject):
+class IApplicantsContainer(IKOFAObject):
     """An applicants container contains university applicants.
 
@@ -352,5 +352,5 @@
     'provider'].order =  IApplicantsContainer['provider'].order
 
-class IApplicantBaseData(ISIRPObject):
+class IApplicantBaseData(IKOFAObject):
     """The data for an applicant.
 
@@ -361,5 +361,5 @@
 
     This base interface is also implemented by the
-    :class:`waeup.sirp.students.StudentApplication` class in the
+    :class:`waeup.kofa.students.StudentApplication` class in the
     students package. Thus, these are the data which are saved after
     admission.
@@ -589,5 +589,5 @@
 
       import grok
-      from waeup.sirp.applicants.interfaces import IApplicantsContainerProvider
+      from waeup.kofa.applicants.interfaces import IApplicantsContainerProvider
 
       class MyContainerProvider(grok.GlobalUtility):
@@ -601,5 +601,5 @@
 
       >>> from zope.component import getAllUtilitiesRegisteredFor
-      >>> from waeup.sirp.applicants.interfaces import (
+      >>> from waeup.kofa.applicants.interfaces import (
       ...     IApplicantsContainerProvider)
       >>> all_providers = getAllUtilitiesRegisteredFor(
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/payment.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/payment.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/payment.py	(revision 7811)
@@ -22,7 +22,7 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.sirp.payments import OnlinePayment
-from waeup.sirp.applicants.interfaces import IApplicantOnlinePayment
-from waeup.sirp.utils.helpers import attrs_to_fields
+from waeup.kofa.payments import OnlinePayment
+from waeup.kofa.applicants.interfaces import IApplicantOnlinePayment
+from waeup.kofa.utils.helpers import attrs_to_fields
 
 class ApplicantOnlinePayment(OnlinePayment):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/pdf.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/pdf.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/pdf.py	(revision 7811)
@@ -32,8 +32,8 @@
 from zope.formlib.form import setUpEditWidgets
 from zope.publisher.browser import TestRequest
-from waeup.sirp.applicants.interfaces import IApplicant
-from waeup.sirp.browser import DEFAULT_PASSPORT_IMAGE_PATH
-from waeup.sirp.interfaces import IExtFileStore, IPDF, ISIRPUtils
-from waeup.sirp.interfaces import MessageFactory as _
+from waeup.kofa.applicants.interfaces import IApplicant
+from waeup.kofa.browser import DEFAULT_PASSPORT_IMAGE_PATH
+from waeup.kofa.interfaces import IExtFileStore, IPDF, IKOFAUtils
+from waeup.kofa.interfaces import MessageFactory as _
 
 SLIP_STYLE = TableStyle(
@@ -54,7 +54,7 @@
     def title(self):
         container_title = self.context.__parent__.title
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         ar_translation = translate(_('Application Record'),
-            'waeup.sirp', target_language=portal_language)
+            'waeup.kofa', target_language=portal_language)
         return '%s - %s %s' % (container_title,
             ar_translation, self.context.application_number)
@@ -107,7 +107,7 @@
         if dept is None:
             return data
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         dp_translation = translate(_('Department:'),
-            'waeup.sirp', target_language=portal_language)
+            'waeup.kofa', target_language=portal_language)
         f_label = '<font size=12>%s</font>' % dp_translation
         f_text = '<font size=12>%s</font>' % dept.longtitle()
@@ -120,5 +120,5 @@
             return data
         fc_translation = translate(_('Faculty:'),
-            'waeup.sirp', target_language=portal_language)
+            'waeup.kofa', target_language=portal_language)
         f_label = '<font size=12>%s</font>' % fc_translation
         f_text = '<font size=12>%s</font>' % faculty.longtitle()
@@ -145,5 +145,5 @@
             pdf.setAuthor('%s (%s)' % (view.request.principal.title,
                 view.request.principal.id))
-        pdf.setCreator('SIRP')
+        pdf.setCreator('KOFA')
         width, height = A4
         style = getSampleStyleSheet()
@@ -171,8 +171,8 @@
         # Render widget fields
         widgets = self._setUpWidgets()
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         for widget in widgets: # self.widgets:
             f_label = '<font size=12>%s</font>:' % translate(
-                widget.label.strip(), 'waeup.sirp',
+                widget.label.strip(), 'waeup.kofa',
                 target_language=portal_language)
             f_label = Paragraph(f_label, style["Normal"])
@@ -184,5 +184,5 @@
             data.append([f_label,f_text])
         adm_translation = translate(_('Admitted Course of Study:'),
-                'waeup.sirp', target_language=portal_language)
+                'waeup.kofa', target_language=portal_language)
         f_label = '<font size=12>%s</font>' % adm_translation
         f_text = '<font size=12>%s</font>' % (
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/root.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/root.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/root.py	(revision 7811)
@@ -23,7 +23,7 @@
 from hurry.query.interfaces import IQuery
 from zope.component import getUtility
-from waeup.sirp.interfaces import ISIRPPluggable
-from waeup.sirp.applicants.interfaces import IApplicantsRoot
-from waeup.sirp.utils.logger import Logger
+from waeup.kofa.interfaces import IKOFAPluggable
+from waeup.kofa.applicants.interfaces import IApplicantsRoot
+from waeup.kofa.utils.logger import Logger
 
 class ApplicantsRoot(grok.Container, Logger):
@@ -35,5 +35,5 @@
     local_roles = []
 
-    logger_name = 'waeup.sirp.${sitename}.applicants'
+    logger_name = 'waeup.kofa.${sitename}.applicants'
     logger_filename = 'applicants.log'
 
@@ -46,15 +46,15 @@
 
 class ApplicantsPlugin(grok.GlobalUtility):
-    """A SIRPPlugin that creates an applicants root in portal.
+    """A KOFAPlugin that creates an applicants root in portal.
 
     This plugin should be called by a typical
-    `waeup.sirp.app.Universtiy` instance on creation time. The
+    `waeup.kofa.app.Universtiy` instance on creation time. The
     :meth:`update` method normally can also be triggered manually over
     the main site configuration.
 
-    Implements :class:`waeup.sirp.interfaces.ISIRPPluggable`
+    Implements :class:`waeup.kofa.interfaces.IKOFAPluggable`
     """
     grok.name('applicants')
-    grok.implements(ISIRPPluggable)
+    grok.implements(IKOFAPluggable)
     log_prefix = 'ApplicantsPlugin'
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/sample_container_data.csv
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/sample_container_data.csv	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/sample_container_data.csv	(revision 7811)
@@ -1,3 +1,3 @@
 code,ac_prefix,application_category,provider,prefix,year
-CODE1,APP,basic,waeup.sirp.applicants.ApplicantsContainer,app,2013
-CODE2,DPP,cest,waeup.sirp.applicants.ApplicantsContainer,app,2013
+CODE1,APP,basic,waeup.kofa.applicants.ApplicantsContainer,app,2013
+CODE2,DPP,cest,waeup.kofa.applicants.ApplicantsContainer,app,2013
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicant.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicant.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicant.py	(revision 7811)
@@ -26,17 +26,17 @@
 from zope.interface import verify, implements
 from zope.location.interfaces import ILocation
-from waeup.sirp.image.interfaces import ISIRPImageFile
-from waeup.sirp.imagestorage import DefaultStorage
-from waeup.sirp.interfaces import IFileStoreHandler, IFileStoreNameChooser
-from waeup.sirp.applicants import (
+from waeup.kofa.image.interfaces import IKOFAImageFile
+from waeup.kofa.imagestorage import DefaultStorage
+from waeup.kofa.interfaces import IFileStoreHandler, IFileStoreNameChooser
+from waeup.kofa.applicants import (
     Applicant, ApplicantFactory,
     ApplicantImageStoreHandler, ApplicantImageNameChooser,
     )
-from waeup.sirp.applicants.interfaces import IApplicant
-from waeup.sirp.testing import FunctionalTestCase, FunctionalLayer
+from waeup.kofa.applicants.interfaces import IApplicant
+from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
 
 class FakeImageLocation(object):
     implements(ILocation)
-    adapts(ISIRPImageFile)
+    adapts(IKOFAImageFile)
     def __init__(self, context):
         pass
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicantcopier.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicantcopier.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicantcopier.py	(revision 7811)
@@ -22,7 +22,7 @@
 from hurry.workflow.interfaces import IWorkflowInfo
 from zope.component import getUtility
-from waeup.sirp.testing import FunctionalLayer
-from waeup.sirp.interfaces import IExtFileStore, IFileStoreNameChooser
-from waeup.sirp.applicants.tests.test_browser import ApplicantsFullSetup
+from waeup.kofa.testing import FunctionalLayer
+from waeup.kofa.interfaces import IExtFileStore, IFileStoreNameChooser
+from waeup.kofa.applicants.tests.test_browser import ApplicantsFullSetup
 
 class ApplicantCopierFunctionalTests(ApplicantsFullSetup):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_authentication.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_authentication.py	(revision 7811)
@@ -25,10 +25,10 @@
 from zope.securitypolicy.role import Role
 from zope.securitypolicy.interfaces import IRole, Allow
-from waeup.sirp.authentication import get_principal_role_manager
-from waeup.sirp.interfaces import IAuthPluginUtility, IUserAccount
-from waeup.sirp.applicants.authentication import (
+from waeup.kofa.authentication import get_principal_role_manager
+from waeup.kofa.interfaces import IAuthPluginUtility, IUserAccount
+from waeup.kofa.applicants.authentication import (
     ApplicantsAuthenticatorSetup, ApplicantAccount)
-from waeup.sirp.applicants.tests.test_browser import ApplicantsFullSetup
-from waeup.sirp.testing import FunctionalLayer
+from waeup.kofa.applicants.tests.test_browser import ApplicantsFullSetup
+from waeup.kofa.testing import FunctionalLayer
 
 class ApplicantsAuthenticatorSetupTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_batching.py	(revision 7811)
@@ -27,13 +27,13 @@
 from zope.interface.verify import verifyClass, verifyObject
 
-from waeup.sirp.app import University
-from waeup.sirp.applicants.batching import (
+from waeup.kofa.app import University
+from waeup.kofa.applicants.batching import (
     ApplicantsContainerImporter, ApplicantImporter)
-from waeup.sirp.applicants.container import ApplicantsContainer
-from waeup.sirp.applicants.applicant import Applicant
-from waeup.sirp.university.faculty import Faculty
-from waeup.sirp.university.department import Department
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.interfaces import IBatchProcessor
+from waeup.kofa.applicants.container import ApplicantsContainer
+from waeup.kofa.applicants.applicant import Applicant
+from waeup.kofa.university.faculty import Faculty
+from waeup.kofa.university.department import Department
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.interfaces import IBatchProcessor
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 7811)
@@ -29,13 +29,13 @@
 from zope.testbrowser.testing import Browser
 from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.app import University
-from waeup.sirp.configuration import SessionConfiguration
-from waeup.sirp.applicants.container import ApplicantsContainer
-from waeup.sirp.applicants.applicant import Applicant
-from waeup.sirp.interfaces import (
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.app import University
+from waeup.kofa.configuration import SessionConfiguration
+from waeup.kofa.applicants.container import ApplicantsContainer
+from waeup.kofa.applicants.applicant import Applicant
+from waeup.kofa.interfaces import (
     IExtFileStore, IFileStoreNameChooser, IUserAccount)
-from waeup.sirp.university.faculty import Faculty
-from waeup.sirp.university.department import Department
+from waeup.kofa.university.faculty import Faculty
+from waeup.kofa.university.department import Department
 
 PH_LEN = 2059  # Length of placeholder file
@@ -247,5 +247,5 @@
         self.browser.getControl(name="form.year").value = ['2010']
         self.browser.getControl(name="form.provider").value = [
-            'waeup.sirp.applicants.ApplicantsContainer']
+            'waeup.kofa.applicants.ApplicantsContainer']
         self.browser.getControl(
             name="form.application_category").value = ['basic']
@@ -262,5 +262,5 @@
         self.browser.getControl(name="form.year").value = ['2010']
         self.browser.getControl(name="form.provider").value = [
-            'waeup.sirp.applicants.ApplicantsContainer']
+            'waeup.kofa.applicants.ApplicantsContainer']
         self.browser.getControl(
             name="form.application_category").value = ['basic']
@@ -277,5 +277,5 @@
         self.browser.getControl(name="form.year").value = ['2010']
         self.browser.getControl(name="form.provider").value = [
-            'waeup.sirp.applicants.ApplicantsContainer']
+            'waeup.kofa.applicants.ApplicantsContainer']
         #self.browser.getControl(name="form.ac_prefix").value = ['APP']
         self.browser.getControl(
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_catalog.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_catalog.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_catalog.py	(revision 7811)
@@ -28,8 +28,8 @@
 from zope.component.interfaces import ComponentLookupError
 from zope.testbrowser.testing import Browser
-from waeup.sirp.app import University
-from waeup.sirp.applicants.container import ApplicantsContainer
-from waeup.sirp.applicants.applicant import Applicant
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.app import University
+from waeup.kofa.applicants.container import ApplicantsContainer
+from waeup.kofa.applicants.applicant import Applicant
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 
 class CatalogTests(FunctionalTestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_container.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_container.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_container.py	(revision 7811)
@@ -21,6 +21,6 @@
 import unittest
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.applicants import interfaces
-from waeup.sirp.applicants.container import (
+from waeup.kofa.applicants import interfaces
+from waeup.kofa.applicants.container import (
     ApplicantsContainer,
     )
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_dynamicroles.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_dynamicroles.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_dynamicroles.py	(revision 7811)
@@ -24,7 +24,7 @@
 from zope.securitypolicy.tests.test_annotationprincipalrolemanager import (
     Test as APRMTest, Manageable)
-from waeup.sirp.testing import FunctionalLayer
-from waeup.sirp.applicants.tests.test_browser import ApplicantsFullSetup
-from waeup.sirp.applicants import ApplicantPrincipalRoleManager
+from waeup.kofa.testing import FunctionalLayer
+from waeup.kofa.applicants.tests.test_browser import ApplicantsFullSetup
+from waeup.kofa.applicants import ApplicantPrincipalRoleManager
 
 class ApplicantPrincipalRoleManagerTests(APRMTest):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_interfaces.py	(revision 7811)
@@ -22,6 +22,6 @@
 from zc.sourcefactory.browser.source import FactoredTerms
 from zope.publisher.browser import TestRequest
-from waeup.sirp.applicants.interfaces import ApplicationTypeSource
-from waeup.sirp.students.vocabularies import GenderSource
+from waeup.kofa.applicants.interfaces import ApplicationTypeSource
+from waeup.kofa.students.vocabularies import GenderSource
 
 class InterfacesTest(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_payment.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_payment.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_payment.py	(revision 7811)
@@ -20,8 +20,8 @@
 """
 
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.applicants.payment import (
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.applicants.payment import (
     ApplicantOnlinePayment, ApplicantOnlinePaymentFactory)
-from waeup.sirp.payments.interfaces import IOnlinePayment
+from waeup.kofa.payments.interfaces import IOnlinePayment
 
 class ApplicantOnlinePaymentFactoryTest(FunctionalTestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_pdf.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_pdf.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_pdf.py	(revision 7811)
@@ -22,8 +22,8 @@
 from zope.component import getAdapter
 from zope.interface import verify
-from waeup.sirp.applicants.pdf import IPDF, PDFApplicationSlip
-from waeup.sirp.applicants.tests.test_browser import ApplicantsFullSetup
-from waeup.sirp.interfaces import IPDF
-from waeup.sirp.testing import FunctionalTestCase, FunctionalLayer
+from waeup.kofa.applicants.pdf import IPDF, PDFApplicationSlip
+from waeup.kofa.applicants.tests.test_browser import ApplicantsFullSetup
+from waeup.kofa.interfaces import IPDF
+from waeup.kofa.testing import FunctionalTestCase, FunctionalLayer
 
 class PDFApplicationSlipTests(ApplicantsFullSetup):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_root.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_root.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_root.py	(revision 7811)
@@ -26,12 +26,12 @@
 from zope.component.hooks import setSite, clearSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.app import University
-from waeup.sirp.applicants import (
+from waeup.kofa.app import University
+from waeup.kofa.applicants import (
     interfaces, Applicant, ApplicantsContainer,
     )
-from waeup.sirp.applicants.root import (
+from waeup.kofa.applicants.root import (
     ApplicantsRoot, ApplicantsPlugin,
     )
-from waeup.sirp.testing import (
+from waeup.kofa.testing import (
     FunctionalLayer, FunctionalTestCase, remove_logger)
 
@@ -45,5 +45,5 @@
 
     def setUp(self):
-        remove_logger('waeup.sirp.app.applicants')
+        remove_logger('waeup.kofa.app.applicants')
         super(ApplicantsRootTestCase, self).setUp()
         # Setup a sample site for each test
@@ -79,5 +79,5 @@
         logger = self.app['applicants'].logger
         assert logger is not None
-        assert logger.name == 'waeup.sirp.app.applicants'
+        assert logger.name == 'waeup.kofa.app.applicants'
         handlers = logger.handlers
         assert len(handlers) == 1
@@ -93,5 +93,5 @@
         logger = self.app['applicants'].logger
         assert logger is not None
-        assert logger.name == 'waeup.sirp.app.applicants'
+        assert logger.name == 'waeup.kofa.app.applicants'
         handlers = logger.handlers
         assert len(handlers) == 1
@@ -103,5 +103,5 @@
     def create_logger(self):
         # create a logger suitable for local tests.
-        test_logger = logging.getLogger('waeup.sirp.applicants.testlogger')
+        test_logger = logging.getLogger('waeup.kofa.applicants.testlogger')
         log = StringIO()
         handler = logging.StreamHandler(log)
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/utils.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/utils.py	(revision 7811)
@@ -20,5 +20,5 @@
 
 import grok
-from waeup.sirp.applicants.interfaces import IApplicantsUtils
+from waeup.kofa.applicants.interfaces import IApplicantsUtils
 
 class ApplicantsUtils(grok.GlobalUtility):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/workflow.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/workflow.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/workflow.py	(revision 7811)
@@ -21,8 +21,8 @@
 from hurry.workflow.workflow import Transition, WorkflowState, NullCondition
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
-from waeup.sirp.applicants.interfaces import IApplicantBaseData
-from waeup.sirp.interfaces import IObjectHistory, ISIRPWorkflowInfo, ISIRPUtils
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.workflow import SIRPWorkflow, SIRPWorkflowInfo
+from waeup.kofa.applicants.interfaces import IApplicantBaseData
+from waeup.kofa.interfaces import IObjectHistory, IKOFAWorkflowInfo, IKOFAUtils
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.workflow import KOFAWorkflow, KOFAWorkflowInfo
 
 INITIALIZED = 'initialized'
@@ -137,5 +137,5 @@
     )
 
-application_workflow = SIRPWorkflow(APPLICATION_TRANSITIONS)
+application_workflow = KOFAWorkflow(APPLICATION_TRANSITIONS)
 
 class ApplicationWorkflowState(WorkflowState, grok.Adapter):
@@ -148,9 +148,9 @@
     state_id = 'wf.application.id'
 
-class ApplicationWorkflowInfo(SIRPWorkflowInfo, grok.Adapter):
+class ApplicationWorkflowInfo(KOFAWorkflowInfo, grok.Adapter):
     """Adapter to adapt Applicant objects to workflow info objects.
     """
     grok.context(IApplicantBaseData)
-    grok.provides(ISIRPWorkflowInfo)
+    grok.provides(IKOFAWorkflowInfo)
 
     def __init__(self, context):

Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 7811)
@@ -28,35 +28,35 @@
 from hurry.workflow.interfaces import (
     IWorkflowInfo, IWorkflowState, InvalidTransitionError)
-from waeup.sirp.applicants.interfaces import (
+from waeup.kofa.applicants.interfaces import (
     IApplicant, IApplicantEdit, IApplicantsRoot,
     IApplicantsContainer, IApplicantsContainerAdd,
     MAX_UPLOAD_SIZE, IApplicantOnlinePayment, IApplicantsUtils
     )
-from waeup.sirp.applicants.workflow import INITIALIZED, STARTED, PAID, SUBMITTED
-from waeup.sirp.browser import (
-    SIRPPage, SIRPEditFormPage, SIRPAddFormPage, SIRPDisplayFormPage,
+from waeup.kofa.applicants.workflow import INITIALIZED, STARTED, PAID, SUBMITTED
+from waeup.kofa.browser import (
+    KOFAPage, KOFAEditFormPage, KOFAAddFormPage, KOFADisplayFormPage,
     DEFAULT_PASSPORT_IMAGE_PATH)
-from waeup.sirp.browser.interfaces import ICaptchaManager
-from waeup.sirp.browser.breadcrumbs import Breadcrumb
-from waeup.sirp.browser.layout import (
+from waeup.kofa.browser.interfaces import ICaptchaManager
+from waeup.kofa.browser.breadcrumbs import Breadcrumb
+from waeup.kofa.browser.layout import (
     NullValidator, jsaction, action, UtilityView)
-from waeup.sirp.browser.pages import add_local_role, del_local_roles
-from waeup.sirp.browser.resources import datepicker, tabs, datatable, warning
-from waeup.sirp.interfaces import (
-    ISIRPObject, ILocalRolesAssignable, IExtFileStore, IPDF,
-    IFileStoreNameChooser, IPasswordValidator, IUserAccount, ISIRPUtils)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.permissions import get_users_with_local_roles
-from waeup.sirp.students.interfaces import IStudentsUtils
-from waeup.sirp.utils.helpers import string_from_bytes, file_size
-from waeup.sirp.widgets.datewidget import (
+from waeup.kofa.browser.pages import add_local_role, del_local_roles
+from waeup.kofa.browser.resources import datepicker, tabs, datatable, warning
+from waeup.kofa.interfaces import (
+    IKOFAObject, ILocalRolesAssignable, IExtFileStore, IPDF,
+    IFileStoreNameChooser, IPasswordValidator, IUserAccount, IKOFAUtils)
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.permissions import get_users_with_local_roles
+from waeup.kofa.students.interfaces import IStudentsUtils
+from waeup.kofa.utils.helpers import string_from_bytes, file_size
+from waeup.kofa.widgets.datewidget import (
     FriendlyDateWidget, FriendlyDateDisplayWidget,
     FriendlyDatetimeDisplayWidget)
-from waeup.sirp.widgets.phonewidget import PhoneWidget
-from waeup.sirp.widgets.restwidget import ReSTDisplayWidget
-
-grok.context(ISIRPObject) # Make ISIRPObject the default context
-
-class ApplicantsRootPage(SIRPPage):
+from waeup.kofa.widgets.phonewidget import PhoneWidget
+from waeup.kofa.widgets.restwidget import ReSTDisplayWidget
+
+grok.context(IKOFAObject) # Make IKOFAObject the default context
+
+class ApplicantsRootPage(KOFAPage):
     grok.context(IApplicantsRoot)
     grok.name('index')
@@ -70,5 +70,5 @@
         return
 
-class ApplicantsRootManageFormPage(SIRPEditFormPage):
+class ApplicantsRootManageFormPage(KOFAEditFormPage):
     grok.context(IApplicantsRoot)
     grok.name('manage')
@@ -141,5 +141,5 @@
         return del_local_roles(self,3,**data)
 
-class ApplicantsContainerAddFormPage(SIRPAddFormPage):
+class ApplicantsContainerAddFormPage(KOFAAddFormPage):
     grok.context(IApplicantsRoot)
     grok.require('waeup.manageApplication')
@@ -215,5 +215,5 @@
         return self.context.p_id
 
-class ApplicantsContainerPage(SIRPDisplayFormPage):
+class ApplicantsContainerPage(KOFADisplayFormPage):
     """The standard view for regular applicant containers.
     """
@@ -232,6 +232,6 @@
     @property
     def introduction(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
         html = self.context.description_dict.get(lang,'')
         if html =='':
@@ -246,5 +246,5 @@
         return "%s" % self.context.title
 
-class ApplicantsContainerManageFormPage(SIRPEditFormPage):
+class ApplicantsContainerManageFormPage(KOFAEditFormPage):
     grok.context(IApplicantsContainer)
     grok.name('manage')
@@ -349,5 +349,5 @@
         return del_local_roles(self,3,**data)
 
-class ApplicantAddFormPage(SIRPAddFormPage):
+class ApplicantAddFormPage(KOFAAddFormPage):
     """Add-form to add an applicant.
     """
@@ -372,5 +372,5 @@
         return
 
-class ApplicantDisplayFormPage(SIRPDisplayFormPage):
+class ApplicantDisplayFormPage(KOFADisplayFormPage):
     grok.context(IApplicant)
     grok.name('index')
@@ -484,5 +484,5 @@
 
 
-class OnlinePaymentDisplayFormPage(SIRPDisplayFormPage):
+class OnlinePaymentDisplayFormPage(KOFADisplayFormPage):
     """ Page to view an online payment ticket
     """
@@ -524,5 +524,5 @@
         self.context.p_state = 'paid'
         self.context.payment_date = datetime.now()
-        ob_class = self.__implemented__.__name__.replace('waeup.sirp.','')
+        ob_class = self.__implemented__.__name__.replace('waeup.kofa.','')
         self.context.__parent__.loggerInfo(
             ob_class, 'valid callback: %s' % self.context.p_id)
@@ -547,13 +547,13 @@
     @property
     def title(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        return translate(_('Payment Data'), 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        return translate(_('Payment Data'), 'waeup.kofa',
             target_language=portal_language)
 
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         return translate(_('Online Payment Receipt'),
-            'waeup.sirp', target_language=portal_language) \
+            'waeup.kofa', target_language=portal_language) \
             + ' %s' % self.context.p_id
 
@@ -582,8 +582,8 @@
     #@property
     #def label(self):
-    #    portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+    #    portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
     #    container_title = self.context.__parent__.title
     #    label = translate('Application Record',
-    #        'waeup.sirp', target_language=portal_language)
+    #        'waeup.kofa', target_language=portal_language)
     #    return container_title +  label + self.context.application_number
 
@@ -638,5 +638,5 @@
     return True
 
-class ApplicantManageFormPage(SIRPEditFormPage):
+class ApplicantManageFormPage(KOFAEditFormPage):
     """A full edit view for applicant data.
     """
@@ -716,5 +716,5 @@
             self.wf_info.fireTransition(trans_id)
         self.flash(_('Form has been saved.'))
-        ob_class = self.__implemented__.__name__.replace('waeup.sirp.','')
+        ob_class = self.__implemented__.__name__.replace('waeup.kofa.','')
         if fields_string:
             self.context.loggerInfo(ob_class, 'saved: % s' % fields_string)
@@ -748,5 +748,5 @@
             self.flash(_('Successfully removed: ${a}',
                 mapping = {'a':', '.join(deleted)}))
-            ob_class = self.__implemented__.__name__.replace('waeup.sirp.','')
+            ob_class = self.__implemented__.__name__.replace('waeup.kofa.','')
             self.context.loggerInfo(
                 ob_class, 'removed: % s' % ', '.join(deleted))
@@ -883,5 +883,5 @@
         return image
 
-class ApplicantRegistrationPage(SIRPAddFormPage):
+class ApplicantRegistrationPage(KOFAAddFormPage):
     """Captcha'd registration page for applicants.
     """
@@ -926,11 +926,11 @@
         self.applyData(applicant, **data)
         self.context.addApplicant(applicant)
-        sirp_utils = getUtility(ISIRPUtils)
-        password = sirp_utils.genPassword()
+        kofa_utils = getUtility(IKOFAUtils)
+        password = kofa_utils.genPassword()
         IUserAccount(applicant).setPassword(password)
         # Send email with credentials
         login_url = self.url(grok.getSite(), 'login')
         msg = _('You have successfully been registered for the')
-        if sirp_utils.sendCredentials(IUserAccount(applicant),
+        if kofa_utils.sendCredentials(IUserAccount(applicant),
             password, login_url, msg):
             self.redirect(self.url(self.context, 'registration_complete',
@@ -941,5 +941,5 @@
         return
 
-class ApplicantRegistrationEmailSent(SIRPPage):
+class ApplicantRegistrationEmailSent(KOFAPage):
     """Landing page after successful registration.
     """
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 7811)
@@ -18,19 +18,19 @@
 import grok
 from hurry.workflow.interfaces import IWorkflowState
-from waeup.sirp.interfaces import ISIRPObject
-from waeup.sirp.students.viewlets import PrimaryStudentNavTab
-from waeup.sirp.browser.viewlets import ManageActionButton, PrimaryNavTab
-from waeup.sirp.applicants.interfaces import (
+from waeup.kofa.interfaces import IKOFAObject
+from waeup.kofa.students.viewlets import PrimaryStudentNavTab
+from waeup.kofa.browser.viewlets import ManageActionButton, PrimaryNavTab
+from waeup.kofa.applicants.interfaces import (
     IApplicant, IApplicantsRoot, IApplicantsContainer,
     IApplicantOnlinePayment,
     )
-from waeup.sirp.applicants.browser import (
+from waeup.kofa.applicants.browser import (
     ApplicantsRootPage, ApplicantsContainerPage, ApplicantManageFormPage,
     ApplicantDisplayFormPage, OnlinePaymentDisplayFormPage
     )
 
-from waeup.sirp.interfaces import MessageFactory as _
+from waeup.kofa.interfaces import MessageFactory as _
 
-grok.context(ISIRPObject) # Make ISIRPObject the default context
+grok.context(IKOFAObject) # Make IKOFAObject the default context
 grok.templatedir('browser_templates')
 
@@ -38,5 +38,5 @@
     """Applicants tab in primary navigation.
     """
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.order(3)
     grok.require('waeup.viewApplicantsTab')